@@ -1,10 +1,7 @@
 use strict;
 use warnings;
 package Test::RequiresInternet;
-{
-  $Test::RequiresInternet::VERSION = '0.02';
-}
-
+$Test::RequiresInternet::VERSION = '0.04';
 # ABSTRACT: Easily test network connectivity
 
 
@@ -78,13 +75,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Test::RequiresInternet - Easily test network connectivity
 
 =head1 VERSION
 
-version 0.02
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -92,11 +91,10 @@ version 0.02
   use Test::RequiresInternet ('www.example.com' => 80, 'foobar.io' => 25);
 
   # if you reach here, sockets successfully connected to hosts/ports above
+  plan tests => 1;
 
   ok(do_that_internet_thing());
 
-  done_testing();
-
 =head1 OVERVIEW
 
 This module is intended to easily test network connectivity before functional 
